# Pacifica Policy API
![PyPi](https://img.shields.io/pypi/v/pacifica-policy.svg)
![Read the Docs](https://readthedocs.org/projects/pacifica-policy/badge/?version=latest)
[![Build Status](https://travis-ci.org/pacifica/pacifica-policy.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-policy)
[![Build status](https://ci.appveyor.com/api/projects/status/rdid7r40620xl12o?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-policy)
[![Code Climate](https://codeclimate.com/github/pacifica/pacifica-policy/badges/gpa.svg)](https://codeclimate.com/github/pacifica/pacifica-policy)
[![Issue Count](https://codeclimate.com/github/pacifica/pacifica-policy/badges/issue_count.svg)](https://codeclimate.com/github/pacifica/pacifica-policy)
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/policy.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/policy/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/policy.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/policy/general)
[![Docker Automated build](https://img.shields.io/docker/automated/pacifica/policy.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/policy/builds)


This is the Pacifica Policy API and implements policy decisions
for the rest of the Pacifica software.

## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-policy.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
* [Configuration](docs/configuration.md) documentation.
* [Examples](docs/exampleusage.md) documentation.
